#!/opt/alt/python38/bin/python3
#
# Wait for IPSD socket is ready
#
import socket as s
import sys
import time

from ipsd_i360.internals import (CONFIG,
                                 ipsd_imunify_config,
                                 logger_init)

ipsdSOCK_PATH = '/var/run/imunify360/libiplists-daemon.sock'
DELAY = 1
TIMEOUT_DEFAULT = 20

logger = logger_init()

if __name__ == '__main__':
    ipsdsock = s.socket(s.AF_UNIX, s.SOCK_STREAM)
    t0 = time.time()
    try:
        timeout = float(ipsd_imunify_config()['socket_readycheck_timeout'])
    except KeyError:
        timeout = TIMEOUT_DEFAULT
    except ValueError as e:
        timeout = TIMEOUT_DEFAULT
        logger.error("%s 'socket_readycheck_timeout=...' key parsing error: %s",
                     CONFIG,
                     e)
    while True:
        try:
            ipsdsock.connect(ipsdSOCK_PATH)
        except (ConnectionRefusedError, FileNotFoundError) as e:
            logger.info("Waiting for ipsd to start (%s)", e)
            if time.time() >= t0 + timeout:
                break
            time.sleep(DELAY)
        else:
            logger.info("ipsd socket is ready.")
            sys.exit(0)
    logger.error("Failed to connect ipsd socket in time.")
    sys.exit(1)
